@@ -947,8 +947,11 @@ static void empty_label_msg (void)
                                                      "During the loading phase, the user can choose to either visualize or delete all these elements all at once. "
                                                      "If not addressed at this stage, they will be highlighted afterward."));
 
-    // Translation note: the verb "close"
-    show_message_dialog (_("Entry of Empty Label Blocked"), "dialog-error", label_txt, _("_Close"));
+    show_message_dialog (_("Entry of Empty Label Blocked"),
+                         "dialog-error",
+                         label_txt,
+                         // Translation note: the verb "Close"
+                         _("_Close"));
 }
 
 /* 
